@@ -74,21 +74,25 @@ split_to_dom_tree(const gchar *tag, Split *spl)
     xmlAddChild(ret, guid_to_dom_tree("split:id", xaccSplitGetGUID(spl)));
 
     {
-        const char *memo = xaccSplitGetMemo(spl);
+        char *memo = g_strdup (xaccSplitGetMemo(spl));
 
         if (memo && g_strcmp0(memo, "") != 0)
         {
-            xmlNewTextChild(ret, NULL, BAD_CAST "split:memo", (xmlChar*)memo);
+            xmlNewTextChild(ret, NULL, BAD_CAST "split:memo",
+			    checked_char_cast (memo));
         }
+	g_free (memo);
     }
 
     {
-        const char *action = xaccSplitGetAction(spl);
+        char *action = g_strdup (xaccSplitGetAction(spl));
 
         if (action && g_strcmp0(action, "") != 0)
         {
-            xmlNewTextChild(ret, NULL, BAD_CAST "split:action", (xmlChar*)action);
+            xmlNewTextChild(ret, NULL, BAD_CAST "split:action",
+			    checked_char_cast (action));
         }
+	g_free (action);
     }
 
     {
@@ -97,7 +101,8 @@ split_to_dom_tree(const gchar *tag, Split *spl)
         tmp[0] = xaccSplitGetReconcile(spl);
         tmp[1] = '\0';
 
-        xmlNewTextChild(ret, NULL, BAD_CAST "split:reconciled-state", (xmlChar*)tmp);
+        xmlNewTextChild(ret, NULL, BAD_CAST "split:reconciled-state",
+			BAD_CAST tmp);
     }
 
     add_timespec(ret, "split:reconcile-date",
@@ -153,31 +158,37 @@ xmlNodePtr
 gnc_transaction_dom_tree_create(Transaction *trn)
 {
     xmlNodePtr ret;
+    gchar *str = NULL;
 
     ret = xmlNewNode(NULL, BAD_CAST "gnc:transaction");
 
-    xmlSetProp(ret, BAD_CAST "version", BAD_CAST transaction_version_string);
+    xmlSetProp(ret, BAD_CAST "version",
+	       BAD_CAST transaction_version_string);
 
     xmlAddChild(ret, guid_to_dom_tree("trn:id", xaccTransGetGUID(trn)));
 
     xmlAddChild(ret, commodity_ref_to_dom_tree("trn:currency",
                 xaccTransGetCurrency(trn)));
-
-    if (xaccTransGetNum(trn) && (g_strcmp0(xaccTransGetNum(trn), "") != 0))
+    str = g_strdup (xaccTransGetNum(trn));
+    if (str && (g_strcmp0(str, "") != 0))
     {
-        xmlNewTextChild(ret, NULL, BAD_CAST "trn:num", (xmlChar*)xaccTransGetNum(trn));
+        xmlNewTextChild(ret, NULL, BAD_CAST "trn:num",
+			checked_char_cast (str));
     }
+    g_free (str);
 
     add_timespec(ret, "trn:date-posted", xaccTransRetDatePostedTS(trn), TRUE);
 
     add_timespec(ret, "trn:date-entered",
                  xaccTransRetDateEnteredTS(trn), TRUE);
 
-    if (xaccTransGetDescription(trn))
+    str = g_strdup (xaccTransGetDescription(trn));
+    if (str)
     {
         xmlNewTextChild(ret, NULL, BAD_CAST "trn:description",
-                        (xmlChar*)xaccTransGetDescription(trn));
+                        checked_char_cast (str));
     }
+    g_free (str);
 
     {
         xmlNodePtr kvpnode = kvp_frame_to_dom_tree("trn:slots",
