@@ -37,7 +37,6 @@
 #include "dialog-utils.h"
 #include "dialog-file-access.h"
 #include "assistant-hierarchy.h"
-#include "assistant-utils.h"
 #include "gnc-amount-edit.h"
 #include "gnc-currency-edit.h"
 #include "gnc-exp-parser.h"
@@ -136,7 +135,7 @@ destroy_hash_helper (gpointer key, gpointer value, gpointer user_data)
 }
 
 static void
-gnc_hierarchy_destroy_cb (GtkObject *obj,   hierarchy_data *data)
+gnc_hierarchy_destroy_cb (GtkWidget *obj,   hierarchy_data *data)
 {
     GHashTable *hash;
 
@@ -1170,8 +1169,6 @@ gnc_create_hierarchy_assistant (gboolean use_defaults, GncHierarchyAssistantFini
     if (when_completed != NULL)
         gtk_window_set_keep_above (GTK_WINDOW(data->dialog), TRUE);
 
-    gnc_assistant_set_colors (GTK_ASSISTANT (data->dialog));
-
     /* Enable buttons on first and last page. */
     gtk_assistant_set_page_complete (GTK_ASSISTANT (dialog),
                                      GTK_WIDGET(gtk_builder_get_object(builder, "intro_page_label")),
