@@ -41,6 +41,7 @@
 #include "gnc-report.h"
 #include "gnc-plugin-page-report.h"
 
+#define GNC_PREFS_GROUP_REPORT_SAVED_CONFIGS "dialogs.report-saved-configs"
 
 /* convenience for accessing columns in the GtkListStore that holds
    the reports */
@@ -79,6 +80,7 @@ typedef struct _CustomReportDialog
 } CustomReportDialog;
 
 void custom_report_dialog_close_cb(GtkWidget* widget, gpointer data);
+void custom_report_help_cb(GtkWidget* widget, gpointer data);
 void close_custom_report_clicked_cb(GtkWidget* widget, gpointer data);
 void custom_report_list_view_row_activated_cb(GtkTreeView *view, GtkTreePath *path,
         GtkTreeViewColumn *column, gpointer data);
@@ -95,10 +97,17 @@ void
 custom_report_dialog_close_cb(GtkWidget* widget, gpointer data)
 {
     CustomReportDialog *crd = data;
+    gnc_save_window_size(GNC_PREFS_GROUP_REPORT_SAVED_CONFIGS, GTK_WINDOW(crd->dialog));
+
     gtk_widget_destroy(crd->dialog);
     g_free(crd);
 }
 
+void
+custom_report_help_cb (GtkWidget *widget, gpointer data)
+{
+    gnc_gnome_help(HF_HELP, HL_USAGE_CUSTOMREP);
+}
 
 void
 close_custom_report_clicked_cb(GtkWidget* widget, gpointer data)
@@ -497,6 +506,8 @@ static CustomReportDialog *gnc_ui_custom_report_internal(GncMainWindow * window)
     set_reports_view_and_model(crd);
     crd->window = window;
 
+    gnc_restore_window_size (GNC_PREFS_GROUP_REPORT_SAVED_CONFIGS, GTK_WINDOW(crd->dialog));
+
     /* connect the signals */
     gtk_builder_connect_signals_full (builder, gnc_builder_connect_full_func, crd);
 
